fill_limbs_from_be_slice_truncated

Function fill_limbs_from_be_slice_truncated 

pub(crate) fn fill_limbs_from_be_slice_truncated(
    bytes: &[u8],
    limbs: &mut [Limb],
    bits_precision: u32,
) -> Result<(), DecodeError>
Common implementation of a truncating big endian decoder which supports partial inputs and truncates inputs larger than the provided bits_precision.

Fills the supplied limbs with the decoded bytes after truncating to bits_precision.