radix_encode_limbs_mut_to_string

Function radix_encode_limbs_mut_to_string 

pub(crate) fn radix_encode_limbs_mut_to_string(
    radix: u32,
    limbs: &mut UintRef,
) -> String
Encode a slice of limbs to a string in base radix. The contents of the slice will be used as a working buffer. The result will have no leading zeros unless the value itself is zero.

Panics

  • if radix is not in the range from 2 to 36.