fn radix_encode_limbs_by_shifting(radix: u32, limbs: &UintRef, out: &mut [u8])Expand description
For radix values which are a power of two, encode the mutable limb slice to
the output buffer as ASCII characters in base radix. Leading zeros are added to
fill out. The slice limbs is used as a working buffer. Output will be truncated
if the provided buffer is too small.