pub(crate) struct RadixDivisionParams {
radix: u32,
digits_per_limb: usize,
bits_per_limb: u32,
recip_limb: Reciprocal,
digits_large: usize,
div_large: [Limb; 16],
recip_large: Reciprocal,
shift_large: u32,
}Expand description
Parameter set used to perform radix encoding by division.
Fields
radix: u32digits_per_limb: usizebits_per_limb: u32recip_limb: Reciprocaldigits_large: usizediv_large: [Limb; 16]recip_large: Reciprocalshift_large: u32Implementations
Sourceimpl RadixDivisionParams
impl RadixDivisionParams
const ALL: [Self; 31]
pub const fn for_radix(radix: u32) -> Self
Sourcepub const fn encoded_size(&self, limb_count: usize) -> usize
pub const fn encoded_size(&self, limb_count: usize) -> usize
Get the minimum size of the required output buffer for encoding a set of limbs.
Sourcepub fn encode_limbs(&self, limbs: &mut UintRef, out: &mut [u8])
pub fn encode_limbs(&self, limbs: &mut UintRef, out: &mut [u8])
Encode the mutable limb slice to the output buffer as ASCII characters in base
radix. Leading zeros are added to fill out. The slice limbs is used as a
working buffer. Output will be truncated if the provided buffer is too small.
fn encode_limbs_small(&self, limbs: &mut UintRef, out: &mut [u8])